@@ -5,7 +5,6 @@ They are invoked from cli/pycompss.py and uses core/cmd.py.
 
 from pycompss_cli.core.actions import Actions
 from pycompss_cli.core.docker.cmd import DockerCmd
-import pycompss_cli.core.docker.cmd as docker_cmd
 from glob import glob
 import os, traceback
  
@@ -95,13 +94,13 @@ class DockerActions(Actions):
         if '--master_name' not in app_args:
             app_args.insert(0, f"--master_name={self.env_conf['master_ip']} ")
         if '--base_log_dir' not in app_args:
-            app_args.insert(0, f'--base_log_dir={docker_cmd.default_workdir} ')
+            app_args.insert(0, '--base_log_dir=/home/user ')
 
         command = "runcompss " + ' '.join(app_args)
 
         self.docker_cmd.docker_exec_in_daemon(command)
 
-        self.docker_cmd.docker_exec_in_daemon(f'cp -a {docker_cmd.default_workdir}.COMPSs/. /root/.COMPSs/')
+        self.docker_cmd.docker_exec_in_daemon('cp -a /home/user/.COMPSs/. /root/.COMPSs/')
 
 
     def monitor(self):
