@@ -1,6 +1,4 @@
-import sys
 import argparse
-import os
 
 FORMATTER_CLASS = argparse.ArgumentDefaultsHelpFormatter
 
