@@ -6,7 +6,6 @@ import tempfile
 import shutil
 from uuid import uuid4
 import subprocess
-from pycompss_cli.core import utils
 
 from pycompss_cli.core.cmd_helpers import command_runner
 
@@ -17,7 +16,7 @@ from pycompss_cli.core.cmd_helpers import command_runner
 master_name = "pycompss-master"
 worker_name = "pycompss-worker"
 service_name = "pycompss-service"
-default_workdir = "/home/jenkins/"
+default_workdir = "/home/user/"
 default_worker_workdir = default_workdir + ".COMPSsWorker"
 default_cfg_file = "cfg"
 default_cfg = default_workdir + default_cfg_file
@@ -89,8 +88,7 @@ class DockerCmd(object):
     def docker_deploy_compss(self, working_dir,
                             image: str = "",
                             restart: bool = True,
-                            privileged: bool = False,
-                            extra_mounts: dict = {}) -> None:
+                            privileged: bool = False) -> None:
         """ Starts the main COMPSs image in Docker.
         It stops any existing one since it can not coexist with itself.
 
@@ -120,22 +118,7 @@ class DockerCmd(object):
                 "while because it needs to download the docker image. " +
                 "Please be patient.")
             subprocess.run(f'docker pull {docker_image}', shell=True)
-
-            inside_docker = utils.is_inside_docker()
-
-            if utils.is_debug():
-                print('\t', '******', 'inside_docker: ', inside_docker)
-
-            if inside_docker:
-                for vol in self.client.volumes.list():
-                    if utils.is_debug():
-                        print('\t', '******', 'volume found: ', vol.name)
-                    if vol.name not in extra_mounts and vol.name == 'JenkinsTestVol':
-                        if utils.is_debug():
-                            print('\t', '******', 'mounting JenkinsTestVol')
-                        extra_mounts[vol.name] = '/home/jenkins/tests_execution_sandbox'
-
-            mounts = self._get_mounts(user_working_dir=working_dir, extra_mounts=extra_mounts)
+            mounts = self._get_mounts(user_working_dir=working_dir)
             ports = {"8888/tcp": 8888,  # required for jupyter notebooks
                     "8080/tcp": 8080}  # required for monitor
             m = self.client.containers.run(image=docker_image, name=master_name,
@@ -389,7 +372,7 @@ class DockerCmd(object):
                 " OF MASTER CONTAINER!!!")
 
 
-    def _get_mounts(self, user_working_dir: str, extra_mounts: dict={}) -> list:
+    def _get_mounts(self, user_working_dir: str) -> list:
         """ Retrieve the list of folders to be mounted. It gets the Mount object
         from the given user working directory, and can include any other needed
         folder.
@@ -402,18 +385,6 @@ class DockerCmd(object):
         user_dir = Mount(target=target_dir,
                         source=user_working_dir,
                         type="bind")
-
-        mounts = [user_dir] if not utils.is_inside_docker() else []
-        for source, target in extra_mounts.items():
-            if utils.is_debug():
-                print('\t', '******', 'Adding extra mount', source, target)
-            mounts.append(Mount(target=target,
-                                source=source,
-                                type="volume"))
-        
-        if utils.is_debug():
-            print('\t', '******', mounts)
-        
         # WARNING: mounting .COMPSs makes it fail
         # compss_logs_dir = os.environ["HOME"] + f"/.COMPSs"
         # os.makedirs(compss_logs_dir, exist_ok=True)
@@ -421,7 +392,7 @@ class DockerCmd(object):
         # compss_log_dir = Mount(target="/root/.COMPSs",
         #                        source=compss_logs_dir,
         #                        type="bind")
-         #, compss_log_dir]
+        mounts = [user_dir]
         return mounts
 
 
